{% extends "base/base.html" %}
{% block body %}
<div class="container">
    <div class="row">
        <h1 style="text-align:center;">L.I.S.A - Authentification</h1>
    </div>

    <div class="row">
        <form class="well span4 offset4" action="{% url 'login' %}" method="POST">{% csrf_token %}
            <div id="messages">
                {% include "base/messages.html" %}
            </div>
            <input type="text" name="username" placeholder="login" style="width:95%">
            <input type="password" name="password" placeholder="password" style="width:95%">
            <input class="btn" type="submit" value="Connexion">
        </form>
    </div>
</div>
{% endblock %}