<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="utf-8">
        <title>{{ title }}</title>
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta name="description" content="">
        <meta name="author" content="">


        <link href="/static/css/bootstrap.css" rel="stylesheet">
        <link href="/static/css/bootstrap-responsive.css" rel="stylesheet">
        <link href="/static/css/darkstrap.css" rel="stylesheet">
        <link href="/static/css/font-awesome.min.css" rel="stylesheet">
        {% block css %}
        <link href="/static/css/my.css" rel="stylesheet">
        {% endblock %}
    </head>
    <body>
    {% block body %}
        {% block header %}
        {% endblock %}
        {% include "base/nav-bar.html" %}
        <div class="container-fluid">
            <div class="row-fluid">
                <div class="">
                    {% block content %}
                    {% endblock %}
                </div>
            </div>
        </div> <!-- /container body -->
    {% endblock %}
        <div class="container-fluid">
            <footer class="footer">
                {% block footer %}
                {% endblock %}
            </footer>
        </div> <!-- /footer -->
        <div class="modal hide fade in" style="display: hidden; width: 800px;" id="myModal">
        </div>
           <!-- Le HTML5 shim, for IE6-8 support of HTML5 elements -->
        <!--[if lt IE 9]>
        <script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
        <![endif]-->

        <script src="/static/js/jquery-1.10.2.js"></script>
        <script src="/static/js/bootstrap.js"></script>
        {% block javascript %}
        <script src="/static/js/my.js"></script>
        {% endblock %}

    </body>
</html>
   
